@@ -92,6 +92,7 @@ class DistributiveSpider(Spider):
         """
         from palp.conn import redis_conn
 
+        modules = {}
         if settings.REQUEST_RETRY_FAILED and redis_conn.exists(settings.REDIS_KEY_QUEUE_BAD_REQUEST):
             while True:
                 request = redis_conn.spop(settings.REDIS_KEY_QUEUE_BAD_REQUEST, count=1)
@@ -109,6 +110,30 @@ class DistributiveSpider(Spider):
                     logger.warning(f"callback 不是 {self.name} 含有的函数：{request}")
                     continue
 
+                # 添加 downloader
+                downloader = request['downloader']
+                key = downloader['module'] + '.' + downloader['init']
+                if key not in modules:
+                    cls = importlib.import_module(downloader['module']).__getattribute__(downloader['init'])  # 导入
+                    modules[key] = cls
+                else:
+                    cls = modules[key]
+
+                request['downloader'] = cls
+
+                # downloader_parser
+                downloader_parser = request['downloader_parser']
+                key = downloader_parser['module'] + '.' + downloader_parser['init']
+                if key not in modules:
+                    cls = importlib.import_module(downloader_parser['module']).__getattribute__(
+                        downloader_parser['init'])  # 导入
+                    modules[key] = cls
+                else:
+                    cls = modules[key]
+
+                request['downloader_parser'] = cls
+
+                # 重构请求
                 request = Request(**request)
 
                 # 为每一个起始函数添加一个 session、cookie_jar
